@@ -3,7 +3,8 @@ from .version import __version__
 __all__ = [
     "__version__",
     "algorithms",
-    "encodings",
+    "circuits",
     "datasets",
-    "circuits"
+    "encodings",
+    "nn",
 ]
