@@ -1,12 +1,16 @@
 from .quantum_estimator import QuantumEstimator
+from .kernel_method_mixin import KernelMethodMixin
 from .qknn import QKNeighborsClassifier, QKNeighborsRegressor
 from .qsvm import QSVClassifier
 from .qkmeans import QKMeans
+from .qridge import QRidgeRegressor
 
 __all__ = [
     "QuantumEstimator",
+    "KernelMethodMixin",
     "QKNeighborsClassifier",
     "QKNeighborsRegressor",
     "QSVClassifier",
-    "QKMeans"
+    "QKMeans",
+    "QRidgeRegressor"
 ]
