@@ -4,10 +4,20 @@ import numpy as np
 
 
 class BasisEncoding(EncodingMap):
-    def circuit(self, x: np.ndarray) -> QuantumCircuit:
+    def __init__(self, n_features: int = 2):
+        """
+        Initializes Basis Encoding Map
+        """
+        super().__init__(n_features)
+        # basis encoding requires 1 qubit
+        # for each feature
+        self._num_qubits = n_features
+
+    def construct_circuit(self, x) -> QuantumCircuit:
         """
         Retrieves the quantum circuit encoding via
         Basis Encoding
+
         Args:
             x: the data vector to encode
 
@@ -20,14 +30,11 @@ class BasisEncoding(EncodingMap):
         if isinstance(x, list):
             x = np.array(x)
 
-        if np.count_nonzero(x == 0) + np.count_nonzero(x == 1) != len(x):
-            raise ValueError("All features must be either 0 or 1 for Basis Encoding")
-
+        self._check_feature_vector(x)
         x = np.array(x)
         x_reversed = x[::-1]  # match Qiskit qubit ordering
 
-        n_qubits = self.n_qubits(x)
-        qc = QuantumCircuit(n_qubits)
+        qc = QuantumCircuit(self.num_qubits)
 
         one_indices = np.where(x_reversed == 1)[0]
         for i in one_indices:
@@ -35,8 +42,7 @@ class BasisEncoding(EncodingMap):
 
         return qc
 
-    def n_qubits(self, x):
-        return len(x)
-
-    def state_vector(self, x):
-        return ''.join(str(s) for s in x)
+    def _check_feature_vector(self, x):
+        if np.count_nonzero(x == 0) + np.count_nonzero(x == 1) != len(x):
+            raise ValueError("All features must be either 0 or 1 for Basis Encoding.")
+        super()._check_feature_vector(x)
